function [b CrossoverPoints] = ERBFilterBank(fs, n, plotflag)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function creates a bank of linear-phase critical band filters.
% The first filter also removes potential DC offsets. 
% Inputs: fs = Sampling rate
% n = Filter Order (Needs to be VERY high to get low freq resolution)
% plotflag: If this is a 1 the function plots the normalised frequency responses
% Example usage: b = LinearPhaseFilterBank(48000, 2^16, 1);
% Recommended: 
% For 44100, n = 2^12
% For 48000, n = 2^12
% For 96000, n = 2^13
%%%%%%%%%%%%%%%% Gavin Kearney 2009 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


CrossoverPoints = [20 100 200 300 400 510 630 770 920 1080 1270 1480 1720 2000 2320 2700 3150 3700 4400 5300 6400 7700 9500 12000 15500];

con = CrossoverPoints/(fs/2);

b(1,:) = fir1(n,  con(2)); % Lowpass filter for 1st band
b(2,:) = fir1(n, [con(2), con(3)]);
b(3,:) = fir1(n, [con(3), con(4)]);
b(4,:) = fir1(n, [con(4), con(5)]);
b(5,:) = fir1(n, [con(5), con(6)]);
b(6,:) = fir1(n, [con(6), con(7)]);
b(7,:) = fir1(n, [con(7), con(8)]);
b(8,:) = fir1(n, [con(8), con(9)]);
b(9,:) = fir1(n, [con(9), con(10)]);
b(10,:) = fir1(n, [con(10), con(11)]);
b(11,:) = fir1(n, [con(11), con(12)]);
b(12,:) = fir1(n, [con(12), con(13)]);
b(13,:) = fir1(n, [con(13), con(14)]);
b(14,:) = fir1(n, [con(14), con(15)]);
b(15,:) = fir1(n, [con(15), con(16)]);
b(16,:) = fir1(n, [con(16), con(17)]);
b(17,:) = fir1(n, [con(17), con(18)]);
b(18,:) = fir1(n, [con(18), con(19)]);
b(19,:) = fir1(n, [con(19), con(20)]);
b(20,:) = fir1(n, [con(20), con(21)]);
b(21,:) = fir1(n, [con(21), con(22)]);
b(22,:) = fir1(n, [con(22), con(23)]);
b(23,:) = fir1(n, [con(23), con(24)]);
b(24,:) = fir1(n, [con(24), con(25)]);
%b(25,:) = fir1(n, [con(25), con(26)]);

if plotflag ==1
    figure()
    for i = 1:size(b)
        freqz(b(i,:));
        hold on;
    end

    figure()
    freqz(sum(b));
end
