function plotFigure(Imp,Fs)
    %create butterworth filters
    % The syntax is [b,a] = butter(filterOrder,[lowCutoff highCutoff]./(0.5*Fs),'bandpass');
    [b1,a1] = butter(3,[44 88]./(0.5*Fs),'bandpass');
    [b2,a2] = butter(3,[88 177]./(0.5*Fs),'bandpass');
    [b3,a3] = butter(3,[177 355]./(0.5*Fs),'bandpass');
    [b4,a4] = butter(3,[355 710]./(0.5*Fs),'bandpass');
    [b5,a5] = butter(3,[710 1420]./(0.5*Fs),'bandpass');
    [b6,a6] = butter(3,[1420 2840]./(0.5*Fs),'bandpass');
    [b7,a7] = butter(3,[2840, 5680]./(0.5*Fs),'bandpass');
    [b8,a8] = butter(3,[5680 11360]./(0.5*Fs),'bandpass');
    
    %Filter RIR by using octave
    Imp_63 = filter(b1,a1,Imp);
    Imp_125 = filter(b2,a2,Imp);
    Imp_250 = filter(b3,a3,Imp);
    Imp_500 = filter(b4,a4,Imp);
    Imp_1000 = filter(b5,a5,Imp);
    Imp_2000 = filter(b6,a6,Imp);
    Imp_4000 = filter(b7,a7,Imp);
    Imp_8000 = filter(b8,a8,Imp);
    
    %Square RIR
    Imp_63 = Imp_63.^2;
    Imp_125 = Imp_125.^2;
    Imp_250 = Imp_250.^2;
    Imp_500 = Imp_500.^2;
    Imp_1000 = Imp_1000.^2;
    Imp_2000 = Imp_2000.^2;
    Imp_4000 = Imp_4000.^2;
    Imp_8000 = Imp_8000.^2;

    %Reverse integrate squared RIR
    if (size(Imp,2) == 1)
        E_63(length(Imp):-1:1) = cumsum(Imp_63(length(Imp):-1:1))./sum(Imp_63);
        E_125(length(Imp):-1:1) = cumsum(Imp_125(length(Imp):-1:1))./sum(Imp_125);
        E_250(length(Imp):-1:1) = cumsum(Imp_250(length(Imp):-1:1))./sum(Imp_250);
        E_500(length(Imp):-1:1) = cumsum(Imp_500(length(Imp):-1:1))./sum(Imp_500);
        E_1000(length(Imp):-1:1) = cumsum(Imp_1000(length(Imp):-1:1))./sum(Imp_1000);
        E_2000(length(Imp):-1:1) = cumsum(Imp_2000(length(Imp):-1:1))./sum(Imp_2000);
        E_4000(length(Imp):-1:1) = cumsum(Imp_4000(length(Imp):-1:1))./sum(Imp_4000);
        E_8000(length(Imp):-1:1) = cumsum(Imp_8000(length(Imp):-1:1))./sum(Imp_8000);
    else
        E_63(length(Imp):-1:1,:) = cumsum(Imp_63(length(Imp):-1:1,:))./sum(Imp_63);
        E_125(length(Imp):-1:1,:) = cumsum(Imp_125(length(Imp):-1:1,:))./sum(Imp_125);
        E_250(length(Imp):-1:1,:) = cumsum(Imp_250(length(Imp):-1:1,:))./sum(Imp_250);
        E_500(length(Imp):-1:1,:) = cumsum(Imp_500(length(Imp):-1:1,:))./sum(Imp_500);
        E_1000(length(Imp):-1:1,:) = cumsum(Imp_1000(length(Imp):-1:1,:))./sum(Imp_1000);
        E_2000(length(Imp):-1:1,:) = cumsum(Imp_2000(length(Imp):-1:1,:))./sum(Imp_2000);
        E_4000(length(Imp):-1:1,:) = cumsum(Imp_4000(length(Imp):-1:1,:))./sum(Imp_4000);
        E_8000(length(Imp):-1:1,:) = cumsum(Imp_8000(length(Imp):-1:1,:))./sum(Imp_8000);
    end
    
    %Calculate energy decay curve of RIR
    E_log_63 = logrithm(E_63);
    E_log_125 = logrithm(E_125);
    E_log_250 = logrithm(E_250);
    E_log_500 = logrithm(E_500);
    E_log_1000 = logrithm(E_1000);
    E_log_2000 = logrithm(E_2000);
    E_log_4000 = logrithm(E_4000);
    E_log_8000 = logrithm(E_8000);
    
    %Calculate EDT, T20, T30 and RT60
    [x_63, EDT_63, T20_63, T30_63] = rtCal(E_log_63,Fs);
    [x_125, EDT_125, T20_125, T30_125] = rtCal(E_log_125,Fs);
    [x_250, EDT_250, T20_250, T30_250] = rtCal(E_log_250,Fs);
    [x_500, EDT_500, T20_500, T30_500] = rtCal(E_log_500,Fs);
    [x_1000, EDT_1000, T20_1000, T30_1000] = rtCal(E_log_1000,Fs);
    [x_2000, EDT_2000, T20_2000, T30_2000] = rtCal(E_log_2000,Fs);
    [x_4000, EDT_4000, T20_4000, T30_4000] = rtCal(E_log_4000,Fs);
    [x_8000, EDT_8000, T20_8000, T30_8000] = rtCal(E_log_8000,Fs);
    
    %Calculate the regression fit line of EDT, T20, T30 and RT60
    [y_EDT_63, y_T20_63, y_T30_63] = regFitLineCal(E_log_63,Fs);
    [y_EDT_125, y_T20_125, y_T30_125] = regFitLineCal(E_log_125,Fs);
    [y_EDT_250, y_T20_250, y_T30_250] = regFitLineCal(E_log_250,Fs);
    [y_EDT_500, y_T20_500, y_T30_500] = regFitLineCal(E_log_500,Fs);
    [y_EDT_1000, y_T20_1000, y_T30_1000] = regFitLineCal(E_log_1000,Fs);
    [y_EDT_2000, y_T20_2000, y_T30_2000] = regFitLineCal(E_log_2000,Fs);
    [y_EDT_4000, y_T20_4000, y_T30_4000] = regFitLineCal(E_log_4000,Fs);
    [y_EDT_8000, y_T20_8000, y_T30_8000] = regFitLineCal(E_log_8000,Fs);
    
    %Plot the energy decay curve
    figure
    subplot(2,2,1)
    plot(x_63,E_log_63)
    hold on 
    plot(x_63,y_EDT_63)
    hold on
    plot(x_63,y_T20_63)
    hold on
    plot(x_63,y_T30_63)
    hold on
    plot([0,length(x_63)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (63Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_63)],['T20 (s) ' num2str(T20_63)],['T30 (s) ' num2str(T30_63)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_63)],['T20 (s) ' num2str(T20_63)],['T30 (s) ' num2str(T30_63)],'-60dB')
    end
    
    subplot(2,2,2)
    plot(x_125,E_log_125)
    hold on 
    plot(x_125,y_EDT_125)
    hold on
    plot(x_125,y_T20_125)
    hold on
    plot(x_125,y_T30_125)
    hold on
    plot([0,length(x_125)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (125Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_125)],['T20 (s) ' num2str(T20_125)],['T30 (s) ' num2str(T30_125)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_125)],['T20 (s) ' num2str(T20_125)],['T30 (s) ' num2str(T30_125)],'-60dB')
    end

    subplot(2,2,3)
    plot(x_250,E_log_250)
    hold on 
    plot(x_250,y_EDT_250)
    hold on
    plot(x_250,y_T20_250)
    hold on
    plot(x_250,y_T30_250)
    hold on
    plot([0,length(x_250)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (250Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_250)],['T20 (s) ' num2str(T20_250)],['T30 (s) ' num2str(T30_250)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_250)],['T20 (s) ' num2str(T20_250)],['T30 (s) ' num2str(T30_250)],'-60dB')
    end
    
    subplot(2,2,4)
    plot(x_500,E_log_500)
    hold on 
    plot(x_500,y_EDT_500)
    hold on
    plot(x_500,y_T20_500)
    hold on
    plot(x_500,y_T30_500)
    hold on
    plot([0,length(x_500)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (500Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_500)],['T20 (s) ' num2str(T20_500)],['T30 (s) ' num2str(T30_500)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_500)],['T20 (s) ' num2str(T20_500)],['T30 (s) ' num2str(T30_500)],'-60dB')
    end
    
    figure
    subplot(2,2,1)
    plot(x_1000,E_log_1000)
    hold on 
    plot(x_1000,y_EDT_1000)
    hold on
    plot(x_1000,y_T20_1000)
    hold on
    plot(x_1000,y_T30_1000)
    hold on
    plot([0,length(x_1000)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (1000Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_1000)],['T20 (s) ' num2str(T20_1000)],['T30 (s) ' num2str(T30_1000)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_1000)],['T20 (s) ' num2str(T20_1000)],['T30 (s) ' num2str(T30_1000)],'-60dB')
    end

    subplot(2,2,2)
    plot(x_2000,E_log_2000)
    hold on 
    plot(x_2000,y_EDT_2000)
    hold on
    plot(x_2000,y_T20_2000)
    hold on
    plot(x_2000,y_T30_2000)
    hold on
    plot([0,length(x_2000)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (2000Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_2000)],['T20 (s) ' num2str(T20_2000)],['T30 (s) ' num2str(T30_2000)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_2000)],['T20 (s) ' num2str(T20_2000)],['T30 (s) ' num2str(T30_2000)],'-60dB')
    end
    
    subplot(2,2,3)
    plot(x_4000,E_log_4000)
    hold on 
    plot(x_4000,y_EDT_4000)
    hold on
    plot(x_4000,y_T20_4000)
    hold on
    plot(x_4000,y_T30_4000)
    hold on
    plot([0,length(x_4000)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (4000Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_4000)],['T20 (s) ' num2str(T20_4000)],['T30 (s) ' num2str(T30_4000)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_4000)],['T20 (s) ' num2str(T20_4000)],['T30 (s) ' num2str(T30_4000)],'-60dB')
    end

    subplot(2,2,4)
    plot(x_8000,E_log_8000)
    hold on
    plot(x_8000,y_EDT_8000)
    hold on
    plot(x_8000,y_T20_8000)
    hold on
    plot(x_8000,y_T30_8000)
    hold on
    plot([0,length(x_8000)],[-60,-60])
    axis([0,6,-100,0]);
    title('Energy Decay curves vs. Time (8000Hz)')
    xlabel('Time (s)')
    ylabel('Erengy (dB)')
    if (size(Imp,2) == 1)
        legend('Energy Decay Curve',['EDT (s) ' num2str(EDT_8000)],['T20 (s) ' num2str(T20_8000)],['T30 (s) ' num2str(T30_8000)],'-60dB')
    else 
        legend('Energy Decay Curve 1','Energy Decay Curve 2',['EDT (s) ' num2str(EDT_8000)],['T20 (s) ' num2str(T20_8000)],['T30 (s) ' num2str(T30_8000)],'-60dB')
    end



    % Realiza a regressao linear (minimos quadrados) dos dados fornecidos (x,y)
    % devolvendo os valores de A e B, sendo (y = A + B*x).
    function    [A,B] = intlinear(x,y)
        mx = mean(x);        my = mean(y);
        mx2 = mean(x.^2);    my2 = mean(y.^2);
        mxy = mean(x.*y);
        A = (mx2*my-mx*mxy)/(mx2-mx^2);
        B = (mxy - (mx*my))/(mx2-mx^2);
    end

    function E_log = logrithm(E)
        %Remove negative values
        if find(E < 0)
            E(min(find(E < 0)):end) = [];
            E_log = 10*log10(E);
        else
            E_log = 10*log10(E);
        end
    end

    function [x, EDT, T20, T30] = rtCal(E_log,Fs)
        x = (0:length(E_log)-1)/Fs;
        t5 = min(find(E_log < -5));
        t10 = min(find(E_log < -10));
        t25 = min(find(E_log < -25));
        t35 = min(find(E_log < -35));

        [A10,B10] = intlinear(x(1:t10),E_log(1:t10));
        [A20,B20] = intlinear(x(t5:t25),E_log(t5:t25));
        [A30,B30] = intlinear(x(t5:t35),E_log(t5:t35));

        EDT = (-60)/(B10);
        T20 = (-60)/(B20);
        T30 = (-60)/(B30);
    end

    function [y_EDT, y_T20, y_T30] = regFitLineCal(E_log,Fs)
        x = (0:length(E_log)-1)/Fs;
        t5 = min(find(E_log < -5));
        t10 = min(find(E_log < -10));
        t25 = min(find(E_log < -25));
        t35 = min(find(E_log < -35));

        %Calculate the regression fit line of EDT
        [A10,B10] = intlinear(x(1:t10),E_log(1:t10));
        y_EDT = B10 * x + A10;   

        %Calculate the regression fit line of T20
        [A20,B20] = intlinear(x(t5:t25),E_log(t5:t25));
        y_T20 = B20 * x + A20; 

        %Calculate the regression fit line of T30 
        [A30,B30] = intlinear(x(t5:t35),E_log(t5:t35));
        y_T30 = B30 * x + A30; 
    end
end
