classdef HMSGreverbPlugin  < audioPlugin & matlab.System
    %HMSGreverbPlugin audioPlugin class generated from HMSGreverberator
    %   Command to generate audio plug-in: generateaudioPlugin HMSGreverbPlugin
    %
    %   See also validateaudioPlugin, generateaudioPlugin.
    
    %   Generated on 29-11月-2022 13:01:00 UTC
    
    properties
        RT60 = 0.1
        ITDG_extension = 0
        Reverb_scale = 1
        Direct_scale = 1
        Corre_coe = 0
    end
    
    properties (Access = private)
        %privObj
        %   This property holds the HMSGreverberator object
        privObjSmall
        privObjMedium
        privObjLarge

        ERDelayL
        ERDelayR

        HRIR_mp_L
        HRIR_mp_R

        pSR

        pFractionalDelay
    end
    
    properties (Constant)
        %PluginInterface
        %   This property defines the audio plugin interface
        PluginInterface = audioPluginInterface( ...
            audioPluginParameter('RT60','DisplayName','Reverb time','Label','s','Mapping',{'lin',0.1,5}),...
            audioPluginParameter('ITDG_extension','DisplayName','ITDG extension','Label','s','Mapping',{'lin',0,0.1}),...
            audioPluginParameter('Reverb_scale','DisplayName','Reverb scale','Mapping',{'lin',0,1}),...
            audioPluginParameter('Direct_scale','DisplayName','Direct sound scale','Mapping',{'lin',0,1}),...
            audioPluginParameter('Corre_coe','DisplayName','Correlation coefficient','Mapping',{'lin',0,1}),...
            'InputChannels',2, ...
            'OutputChannels',2, ...
            'PluginName','HMSGreverbPlugin' ...
            )
    end

    properties (Constant)
        Delvar = 0.1;
        HRIR = audioread('azi_0,0_ele_0,0.wav'); 
        PartitionSize = 128;
    end
    
    methods
        function obj = HMSGreverbPlugin            % validateAudioPlugin HMSGreverbPlugin        audioTestBench(HMSGreverbPlugin)   generateAudioPlugin HMSGreverbPlugin
            Fs = getSampleRate(obj);
            obj.pSR = Fs; 

            obj.privObjSmall = HMSGSmallClassReverberator;
            obj.privObjMedium = HMSGMediumClassReverberator;
            obj.privObjLarge = HMSGLargeClassReverberator;

            ERL_DelayLine = [190,949,993,1183,1192,1315,2021,2140,2524,2590,2625,2700,3119,3123,3202,3268,3321,3515];          
            obj.ERDelayL = dsp.Delay(ERL_DelayLine);
            ERR_DelayLine = round([190,949,993,1183,1192,1315,2021,2140,2524,2590,2625,2700,3119,3123,3202,3268,3321,3515] .* (1 + obj.Delvar));
            obj.ERDelayR = dsp.Delay(ERR_DelayLine);

            HRIR_mp = rceps(obj.HRIR); % Get min phase HRTF just for this example ;
            HRIR_mp = HRIR_mp./max(abs(HRIR_mp));
            obj.HRIR_mp_L = dsp.FrequencyDomainFIRFilter('Numerator', HRIR_mp(:,1).', ...
                    'PartitionForReducedLatency', true, 'PartitionLength', obj.PartitionSize);
            obj.HRIR_mp_R = dsp.FrequencyDomainFIRFilter('Numerator', HRIR_mp(:,2).', ...
                'PartitionForReducedLatency', true, 'PartitionLength', obj.PartitionSize);

            obj.pFractionalDelay = audioexample.DelayFilter('FeedbackLevel', 0, 'SampleRate', Fs);  
        end
    end
    
    methods (Access = protected)
        function setupImpl(obj, x)
            setup(obj.privObjSmall,x);
            setup(obj.privObjMedium,x);
            setup(obj.privObjLarge,x);
        end
        
        function processTunedPropertiesImpl(obj)
            obj.privObjSmall.RT60 = obj.RT60;
            obj.privObjMedium.RT60 = obj.RT60;
            obj.privObjLarge.RT60 = obj.RT60;
        end
        
        function y = stepImpl(obj, x)
            output_Reverb = zeros(size(x));

            if obj.RT60 >= 0.1 && obj.RT60 < 0.58
                output_SER = Reverb_SER(obj,x);
                output_SLR = step(obj.privObjSmall, output_SER);
                output_Reverb = output_SER + output_SLR;
            elseif obj.RT60 >= 0.58 && obj.RT60 < 1.3
                output_Reverb = step(obj.privObjMedium, x);
            elseif obj.RT60 >= 1.3 && obj.RT60 <= 5
                output_Reverb = step(obj.privObjLarge, x);
            end

            output_Reverb_Corre = output_Reverb + fliplr(output_Reverb)*obj.Corre_coe; % If you want to increase channel correlation 

            if size(x, 2) == 1
                output_Dir_L = step(obj.HRIR_mp_L, x);
                output_Dir_R = step(obj.HRIR_mp_R, x);
            elseif(size(x, 2) == 2)
                output_Dir_L = step(obj.HRIR_mp_L, x(:, 1));
                output_Dir_R = step(obj.HRIR_mp_R, x(:, 2));
            end

            output_Dir = [output_Dir_L, output_Dir_R];

            delayInSamples = obj.ITDG_extension * obj.pSR;
            output_Reverb_D = obj.pFractionalDelay(delayInSamples, output_Reverb_Corre(:,1:2));

            y = obj.Direct_scale.*output_Dir + obj.Reverb_scale.*output_Reverb_D;

        end

        function out = Reverb_SER(obj,audio)     
            ER_gain = [0.841,0.504,0.490,0.379,0.380,0.346,0.289,0.272,0.192,0.193,0.217,0.181,0.180,0.181,0.176,0.142,0.167,0.134];                      

            %---------------Left channel--------------%
            if (size(audio, 2) == 1)
                in = audio;
            elseif (size(audio, 2) == 2)
                in = audio(:,1);
            end
        
            ER_tL = repmat(in,size(ER_gain));       
            ER_DoutL = obj.ERDelayL(ER_tL);
            ER_gainLMatrix = repmat(ER_gain,size(in,1),1);
            ER_GoutL = ER_gainLMatrix .* ER_DoutL;

            L_EROut = sum(ER_GoutL,2);
                         
            %---------------Right channel--------------% 
            if (size(audio, 2) == 1)
                in = audio;
            elseif (size(audio, 2) == 2)
                in = audio(:,2);
            end
    
            ER_tR = repmat(in,size(ER_gain));
            ER_DoutR = obj.ERDelayR(ER_tR);
            ER_gainLMatrix = repmat(ER_gain,size(in,1),1);
            ER_GoutR = ER_gainLMatrix .* ER_DoutR;
            
            R_EROut = sum(ER_GoutR,2);

            out = [L_EROut, R_EROut];
        end
        
        function resetImpl(obj)
            obj.privObjSmall.SampleRate = getSampleRate(obj);
            reset(obj.privObjSmall);

            obj.privObjMedium.SampleRate = getSampleRate(obj);
            reset(obj.privObjMedium);

            obj.privObjLarge.SampleRate = getSampleRate(obj);
            reset(obj.privObjLarge);
        end
        
        function releaseImpl(obj)
            release(obj.privObjSmall);
            release(obj.privObjMedium);
            release(obj.privObjLarge);
        end
        
        function s = saveObjectImpl(obj)
            s = saveObjectImpl@matlab.System(obj);
            if isLocked(obj)
                s.privObjSmall = matlab.System.saveObject(obj.privObjSmall);
                s.privObjMedium = matlab.System.saveObject(obj.privObjMedium);
                s.privObjLarge = matlab.System.saveObject(obj.privObjLarge);
            end
        end
        
        function loadObjectImpl(obj, s, wasLocked)
            if wasLocked
                obj.privObjSmall = matlab.System.loadObject(s.privObjSmall);
                obj.privObjMedium = matlab.System.loadObject(s.privObjMedium);
                obj.privObjLarge = matlab.System.loadObject(s.privObjLarge);
            end
            loadObjectImpl@matlab.System(obj,s,wasLocked);
        end
    end
end

% [EOF]
